@@ -20,6 +20,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
@@ -70,6 +71,7 @@ import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
@@ -128,9 +130,11 @@ import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopu
  * Guided Decision Table Graph Editor Presenter
  */
 @Dependent
-@WorkbenchEditor(identifier = "GuidedDecisionTableGraphEditor", supportedTypes = {GuidedDTableGraphResourceType.class}, lockingStrategy = EDITOR_PROVIDED)
+@WorkbenchEditor(identifier = GuidedDecisionTableGraphEditorPresenter.IDENTIFIER, supportedTypes = {GuidedDTableGraphResourceType.class}, lockingStrategy = EDITOR_PROVIDED)
 public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionTableEditorPresenter implements HasSearchableElements<GuidedDecisionTableSearchableElement> {
 
+    public static final String IDENTIFIER = "GuidedDecisionTableGraphEditor";
+
     private final Caller<GuidedDecisionTableGraphEditorService> graphService;
     private final Caller<KieModuleService> moduleService;
     private final Caller<GuidedDecisionTableGraphSaveAndRenameService> graphSaveAndRenameService;
@@ -160,6 +164,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                                                    final Event<NotificationEvent> notification,
                                                    final Event<SaveInProgressEvent> saveInProgressEvent,
                                                    final Event<DecisionTableSelectedEvent> decisionTableSelectedEvent,
+                                                   final GuidedDecisionTableDocksHandler guidedDecisionTableDocksHandler,
+                                                   final AnalysisReportScreen analysisReportScreen,
                                                    final ValidationPopup validationPopup,
                                                    final GuidedDTableGraphResourceType dtGraphResourceType,
                                                    final EditMenuBuilder editMenuBuilder,
@@ -185,6 +191,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
               perspectiveManager,
               notification,
               decisionTableSelectedEvent,
+              guidedDecisionTableDocksHandler,
+              analysisReportScreen,
               validationPopup,
               dtGraphResourceType,
               editMenuBuilder,
@@ -208,6 +216,7 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
         this.searchBarComponent = searchBarComponent;
         this.searchableElementFactory = searchableElementFactory;
         this.searchPerformedEvent = searchPerformedEvent;
+        this.modeller.analysisReportScreen(analysisReportScreen);
     }
 
     @PostConstruct
@@ -335,7 +344,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                 for (int line = 0; line < data.get(row).size(); line++) {
 
                     final DTCellValue52 cellValue52 = data.get(row).get(line);
-                    final GuidedDecisionTableSearchableElement searchableElement = searchableElementFactory.makeSearchableElement(row, line, cellValue52, widget, model, modeller);
+                    final Map<String, String> valueListLookup = widget.getPresenter().getValueListLookups(model.getExpandedColumns().get(line));
+                    final GuidedDecisionTableSearchableElement searchableElement = searchableElementFactory.makeSearchableElement(row, line, cellValue52, widget, model, valueListLookup, modeller);
 
                     searchableElement.setWidget(widget);
                     searchableElements.add(searchableElement);
@@ -385,6 +395,11 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
         super.onFocus();
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return GuidedDecisionTableGraphEditorPresenter.IDENTIFIER;
+    }
+
     @Override
     public void loadDocument(final ObservablePath path,
                              final PlaceRequest placeRequest) {
@@ -719,7 +734,7 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                 view.alertReadOnly();
                 return;
             } else {
-                versionRecordManager.restoreToCurrentVersion();
+                versionRecordManager.restoreToCurrentVersion(saveWithComments);
                 return;
             }
         }
@@ -753,20 +768,27 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
 
     void saveDocumentGraphEntries() {
         final Set<GuidedDecisionTableView.Presenter> allDecisionTables = new HashSet<>(modeller.getAvailableDecisionTables());
-        savePopUpPresenter.show(editorPath,
-                                (commitMessage) -> {
-                                    editorView.showSaving();
-                                    saveGraphLatch = new SaveGraphLatch(allDecisionTables.size(),
-                                                                        commitMessage);
-                                    if (allDecisionTables.isEmpty()) {
-                                        saveGraphLatch.saveDocumentGraph();
-                                    } else {
-                                        allDecisionTables.stream().forEach((dtPresenter) -> {
-                                            saveGraphLatch.saveDocumentGraphEntry(dtPresenter);
-                                            saveInProgressEvent.fire(new SaveInProgressEvent(dtPresenter.getLatestPath()));
-                                        });
-                                    }
-                                });
+
+        final ParameterizedCommand<String> saveCommand = (commitMessage) -> {
+            editorView.showSaving();
+            saveGraphLatch = new SaveGraphLatch(allDecisionTables.size(),
+                                                commitMessage);
+            if (allDecisionTables.isEmpty()) {
+                saveGraphLatch.saveDocumentGraph();
+            } else {
+                allDecisionTables.stream().forEach((dtPresenter) -> {
+                    saveGraphLatch.saveDocumentGraphEntry(dtPresenter);
+                    saveInProgressEvent.fire(new SaveInProgressEvent(dtPresenter.getLatestPath()));
+                });
+            }
+        };
+
+        if (saveWithComments) {
+            savePopUpPresenter.show(editorPath,
+                                    saveCommand);
+        } else {
+            saveCommand.execute("");
+        }
     }
 
     @Override
